BarcodeCalenderEvent class

Stores a calendar event obtained from a barcode.

Inheritance

Constructors

BarcodeCalenderEvent({String? description, String? location, String? status, String? summary, String? organizer, DateTime? start, DateTime? end})
Constructor to create an instance of BarcodeCalenderEvent.
BarcodeCalenderEvent.fromJson(Map json)
Returns an instance of BarcodeCalenderEvent from a given json.
factory

Properties

description → String?
Description of the event.
final
end → DateTime?
End DateTime of the calender event.
final
hashCode → int
The hash code for this object.
no setterinherited
location → String?
Location of the event.
final
organizer → String?
A person or the organisation who is organising the event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → DateTime?
Start DateTime of the calender event.
final
status → String?
Status of the event -> whether the event is completed or not.
final
summary → String?
A short summary of the event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited