PoseData class

A class that has all the information on the body detected

poses The joint information gathered.

Constructors

PoseData(List<Pose> poses)

Properties

hashCode → int
The hash code for this object.
no setterinherited
poses ↔ List<Pose>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited