AppleVisionSaliencyController class

The AppleVisionSaliencyController holds all the logic of this plugin, where as the AppleVisionSaliency class is the frontend of this plugin.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processImage(SaliencySegmentationData data) Future<List<Uint8List?>?>
Process the image using apple vision and return the requested information or null value
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited